@@ -1,4 +1,3 @@
-import sys
 from dataclasses import dataclass
 from textwrap import dedent
 from typing import Any
@@ -811,7 +810,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                return app.query_one(Tree).root
+                return app.screen.query_one(Tree).root
 
         root = async_run(run_test())
 
@@ -847,7 +846,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                return app.query_one(Tree).root
+                return app.screen.query_one(Tree).root
 
         root = async_run(run_test())
 
@@ -934,7 +933,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                return app.query_one(Tree).root
+                return app.screen.query_one(Tree).root
 
         root = async_run(run_test())
 
@@ -1034,7 +1033,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                tree = app.query_one(Tree)
+                tree = app.screen.query_one(Tree)
                 first_tree = tree_to_dict(tree.root)
                 await pilot.press("u")
                 await pilot.pause()
@@ -1165,7 +1164,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                tree = app.query_one(Tree)
+                tree = app.screen.query_one(Tree)
                 first_tree = tree_to_dict(tree.root)
                 await pilot.press("i")
                 await pilot.pause()
@@ -1206,7 +1205,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                tree = app.query_one(Tree)
+                tree = app.screen.query_one(Tree)
                 return tree.root
 
         root = async_run(run_test())
@@ -1267,7 +1266,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                tree = app.query_one(Tree)
+                tree = app.screen.query_one(Tree)
                 first_tree = tree_to_dict(tree.root)
                 await pilot.press("i")
                 await pilot.pause()
@@ -1372,7 +1371,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                tree = app.query_one(Tree)
+                tree = app.screen.query_one(Tree)
                 first_tree = tree_to_dict(tree.root)
                 await pilot.press("i")
                 await pilot.pause()
@@ -1426,7 +1425,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                tree = app.query_one(Tree)
+                tree = app.screen.query_one(Tree)
                 child = tree.root.children[1]
                 # From Textual 0.73 on, Tree.select_node toggles the node's expanded
                 # state. The new Tree.move_cursor method selects without expanding.
@@ -1508,7 +1507,7 @@ class TestTreeTui:
         async def run_test():
             async with app.run_test() as pilot:
                 await pilot.pause()
-                return app.query_one(Tree).root
+                return app.screen.query_one(Tree).root
 
         root = async_run(run_test())
 
@@ -1534,15 +1533,6 @@ class TestTreeTui:
 
 @pytest.fixture
 def compare(monkeypatch, tmp_path, snap_compare):
-    # The snapshots we've generated using current versions of Textual aren't
-    # expected to match anymore on Python 3.7, as Textual dropped support for
-    # Python 3.7 in the 0.44 release. However, we'd still like to run our
-    # snapshot tests on Python 3.7, to confirm that no unexpected exceptions
-    # occur and that the app doesn't crash. So, allow `snap_compare()` to drive
-    # the application, but always return `True` on Python 3.7 as long as no
-    # exception was raised.
-    succeed_even_if_mismatched = sys.version_info < (3, 8)
-
     def compare_impl(
         allocations: Iterator[AllocationRecord],
         press: Iterable[str] = (),
@@ -1561,14 +1551,11 @@ def compare(monkeypatch, tmp_path, snap_compare):
         with monkeypatch.context() as app_patch:
             app_patch.setitem(globals(), app_global, app)
             tmp_main.write_text(f"from {__name__} import {app_global} as app")
-            return (
-                snap_compare(
-                    str(tmp_main),
-                    press=press,
-                    terminal_size=terminal_size,
-                    run_before=run_before,
-                )
-                or succeed_even_if_mismatched
+            return snap_compare(
+                str(tmp_main),
+                press=press,
+                terminal_size=terminal_size,
+                run_before=run_before,
             )
 
     yield compare_impl
